@@ -1,34 +1,23 @@
 """ Satellite Data Source """
 import logging
-from concurrent import futures
 from dataclasses import InitVar, dataclass
-from numbers import Number
 from typing import Iterable, Optional
 
-import numpy as np
 import pandas as pd
 import xarray as xr
 
 import nowcasting_dataset.time as nd_time
+from nowcasting_dataset.consts import SAT_VARIABLE_NAMES
 from nowcasting_dataset.data_sources.data_source import ZarrDataSource
 from nowcasting_dataset.data_sources.satellite.satellite_model import Satellite
-from nowcasting_dataset.dataset.xr_utils import join_list_data_array_to_batch_dataset
 
 _LOG = logging.getLogger("nowcasting_dataset")
 
 
-from nowcasting_dataset.consts import SAT_VARIABLE_NAMES
-
-
 @dataclass
 class SatelliteDataSource(ZarrDataSource):
-    """
-    Satellite Data Source
+    """Satellite Data Source."""
 
-    zarr_path: Must start with 'gs://' if on GCP.
-    """
-
-    zarr_path: str = None
     channels: Optional[Iterable[str]] = SAT_VARIABLE_NAMES
     image_size_pixels: InitVar[int] = 128
     meters_per_pixel: InitVar[int] = 2_000
@@ -36,7 +25,6 @@ class SatelliteDataSource(ZarrDataSource):
     def __post_init__(self, image_size_pixels: int, meters_per_pixel: int):
         """ Post Init """
         super().__post_init__(image_size_pixels, meters_per_pixel)
-        self._cache = {}
         n_channels = len(self.channels)
         self._shape_of_example = (
             self._total_seq_length,
@@ -60,85 +48,57 @@ class SatelliteDataSource(ZarrDataSource):
     def _open_data(self) -> xr.DataArray:
         return open_sat_data(zarr_path=self.zarr_path, consolidated=self.consolidated)
 
-    def get_batch(
-        self,
-        t0_datetimes: pd.DatetimeIndex,
-        x_locations: Iterable[Number],
-        y_locations: Iterable[Number],
-    ) -> Satellite:
-        """
-        Get batch data
-
-        Load the first _n_timesteps_per_batch concurrently.  This
-        loads the timesteps from disk concurrently, and fills the
-        cache.  If we try loading all examples
-        concurrently, then SatelliteDataSource will try reading from
-        empty caches, and things are much slower!
-
-        Args:
-            t0_datetimes: list of timestamps for the datetime of the batches. The batch will also
-                include data for historic and future depending on `history_minutes` and
-                `future_minutes`.
-            x_locations: x center batch locations
-            y_locations: y center batch locations
-
-        Returns: Batch data
-
-        """
-        # Load the first _n_timesteps_per_batch concurrently.  This
-        # loads the timesteps from disk concurrently, and fills the
-        # cache.  If we try loading all examples
-        # concurrently, then SatelliteDataSource will try reading from
-        # empty caches, and things are much slower!
-        zipped = list(zip(t0_datetimes, x_locations, y_locations))
-        batch_size = len(t0_datetimes)
-
-        with futures.ThreadPoolExecutor(max_workers=batch_size) as executor:
-            future_examples = []
-            for coords in zipped[: self.n_timesteps_per_batch]:
-                t0_datetime, x_location, y_location = coords
-                future_example = executor.submit(
-                    self.get_example, t0_datetime, x_location, y_location
-                )
-                future_examples.append(future_example)
-            examples = [future_example.result() for future_example in future_examples]
-
-        # Load the remaining examples.  This should hit the DataSource caches.
-        for coords in zipped[self.n_timesteps_per_batch :]:
-            t0_datetime, x_location, y_location = coords
-            example = self.get_example(t0_datetime, x_location, y_location)
-            examples.append(example)
-
-        output = join_list_data_array_to_batch_dataset(examples)
-
-        self._cache = {}
-
+    def _dataset_to_data_source_output(output: xr.Dataset) -> Satellite:
         return Satellite(output)
 
     def _get_time_slice(self, t0_dt: pd.Timestamp) -> xr.DataArray:
-        try:
-            return self._cache[t0_dt]
-        except KeyError:
-            start_dt = self._get_start_dt(t0_dt)
-            end_dt = self._get_end_dt(t0_dt)
-            data = self.data.sel(time=slice(start_dt, end_dt))
-            data = data.load()
-            self._cache[t0_dt] = data
-            return data
-
-    def _post_process_example(
-        self, selected_data: xr.DataArray, t0_dt: pd.Timestamp
-    ) -> xr.DataArray:
-
-        selected_data.data = selected_data.data.astype(np.float32)
-
-        return selected_data
+        start_dt = self._get_start_dt(t0_dt)
+        end_dt = self._get_end_dt(t0_dt)
+        data = self.data.sel(time=slice(start_dt, end_dt))
+        return data
 
     def datetime_index(self, remove_night: bool = True) -> pd.DatetimeIndex:
         """Returns a complete list of all available datetimes
 
         Args:
             remove_night: If True then remove datetimes at night.
+                We're interested in forecasting solar power generation, so we
+                don't care about nighttime data :)
+
+                In the UK in summer, the sun rises first in the north east, and
+                sets last in the north west [1].  In summer, the north gets more
+                hours of sunshine per day.
+
+                In the UK in winter, the sun rises first in the south east, and
+                sets last in the south west [2].  In winter, the south gets more
+                hours of sunshine per day.
+
+                |                        | Summer | Winter |
+                |           ---:         |  :---: |  :---: |
+                | Sun rises first in     | N.E.   | S.E.   |
+                | Sun sets last in       | N.W.   | S.W.   |
+                | Most hours of sunlight | North  | South  |
+
+                Before training, we select timesteps which have at least some
+                sunlight.  We do this by computing the clearsky global horizontal
+                irradiance (GHI) for the four corners of the satellite imagery,
+                and for all the timesteps in the dataset.  We only use timesteps
+                where the maximum global horizontal irradiance across all four
+                corners is above some threshold.
+
+                The 'clearsky solar irradiance' is the amount of sunlight we'd
+                expect on a clear day at a specific time and location. The SI unit
+                of irradiance is watt per square meter.  The 'global horizontal
+                irradiance' (GHI) is the total sunlight that would hit a
+                horizontal surface on the surface of the Earth.  The GHI is the
+                sum of the direct irradiance (sunlight which takes a direct path
+                from the Sun to the Earth's surface) and the diffuse horizontal
+                irradiance (the sunlight scattered from the atmosphere).  For more
+                info, see: https://en.wikipedia.org/wiki/Solar_irradiance
+
+        References:
+          1. [Video of June 2019](https://www.youtube.com/watch?v=IOp-tj-IJpk)
+          2. [Video of Jan 2019](https://www.youtube.com/watch?v=CJ4prUVa2nQ)
         """
         if self._data is None:
             sat_data = self._open_data()
